==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/newlife/leechcraft_newlife_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>FeedsSettingsImportPage</name>
    <message>
        <location filename="feedssettingsimportpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="22"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="34"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="45"/>
        <source>Import %1 settings as well</source>
        <extracomment>Application&apos;s name will be placed instead of %1, so please leave it where appropriate.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FirstPage</name>
    <message>
        <location filename="firstpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="17"/>
        <source>Choose application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="20"/>
        <source>Choose appication that you want your data to be imported from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="28"/>
        <source>Source application:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportWizard</name>
    <message>
        <location filename="importwizard.ui" line="14"/>
        <source>Wizard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importwizard.ui" line="35"/>
        <source>Now please prepare for the import of data from the selected application.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::AkregatorImportPage</name>
    <message>
        <location filename="akregatorimportpage.cpp" line="40"/>
        <source>Akregator&apos;s feeds import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="41"/>
        <source>Select Akregator&apos;s feeds file and options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="103"/>
        <source>Select Akregator&apos;s OPML file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="105"/>
        <source>OPML files (*.opml *.xml);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="112"/>
        <location filename="akregatorimportpage.cpp" line="155"/>
        <source>LeechCraft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="113"/>
        <source>The file you&apos;ve selected is not a valid OPML file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="151"/>
        <source>Akregator settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="156"/>
        <source>Could not access or parse Akregator settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::LifereaImportPage</name>
    <message>
        <location filename="lifereaimportpage.cpp" line="40"/>
        <source>Liferea&apos;s feeds import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="41"/>
        <source>Select Liferea&apos;s base location and options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="108"/>
        <source>Select Liferea&apos;s directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="117"/>
        <source>LeechCraft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="118"/>
        <source>The directory you&apos;ve selected is not Liferea&apos;s directory.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::Plugin</name>
    <message>
        <location filename="newlife.cpp" line="49"/>
        <source>The settings importer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="newlife.cpp" line="83"/>
        <source>Import settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/newlife/leechcraft_newlife_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>FeedsSettingsImportPage</name>
    <message>
        <location filename="feedssettingsimportpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="22"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="34"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="45"/>
        <source>Import %1 settings as well</source>
        <extracomment>Application&apos;s name will be placed instead of %1, so please leave it where appropriate.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FirstPage</name>
    <message>
        <location filename="firstpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="17"/>
        <source>Choose application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="20"/>
        <source>Choose appication that you want your data to be imported from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="28"/>
        <source>Source application:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportWizard</name>
    <message>
        <location filename="importwizard.ui" line="14"/>
        <source>Wizard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importwizard.ui" line="35"/>
        <source>Now please prepare for the import of data from the selected application.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::AkregatorImportPage</name>
    <message>
        <location filename="akregatorimportpage.cpp" line="40"/>
        <source>Akregator&apos;s feeds import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="41"/>
        <source>Select Akregator&apos;s feeds file and options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="103"/>
        <source>Select Akregator&apos;s OPML file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="105"/>
        <source>OPML files (*.opml *.xml);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="112"/>
        <source>The file you&apos;ve selected is not a valid OPML file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="155"/>
        <source>Akregator settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="160"/>
        <source>Could not access or parse Akregator settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::KTorrentImportPage</name>
    <message>
        <location filename="ktorrentimportpage.cpp" line="41"/>
        <source>KTorrent&apos;s torrents import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="42"/>
        <source>Select KTorrent&apos;s torrents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="85"/>
        <source>Select KTorrent&apos;s configuration file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="95"/>
        <source>Can&apos;t read KTorrent&apos;s configuration file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="182"/>
        <source>KTorrent settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="187"/>
        <source>Could not access or parse KTorrent settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::LifereaImportPage</name>
    <message>
        <location filename="lifereaimportpage.cpp" line="40"/>
        <source>Liferea&apos;s feeds import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="41"/>
        <source>Select Liferea&apos;s base location and options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="108"/>
        <source>Select Liferea&apos;s directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="117"/>
        <source>The directory you&apos;ve selected is not Liferea&apos;s directory.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::Plugin</name>
    <message>
        <location filename="newlife.cpp" line="53"/>
        <source>The settings importer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="newlife.cpp" line="87"/>
        <source>Import settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
